@@ -1,4 +1,5 @@
 package Net::Amazon::EC2::Errors;
+$Net::Amazon::EC2::Errors::VERSION = '0.36';
 use Moose;
 
 =head1 NAME
@@ -23,6 +24,8 @@ An array ref of Net::Amazon::EC2::Error objects associated with this request.
 
 =cut
 
+use overload '""' => 'as_string';
+
 has 'request_id'    => ( is => 'ro', isa => 'Str', required => 1 );
 has 'errors'        => ( 
     is          => 'rw', 
@@ -31,8 +34,16 @@ has 'errors'        => (
     required    => 1,
 );
 
+sub as_string {
+  my $self = shift;
+  my $errors = join '', map { '['.$_->code.'] '.$_->message."\n" } @{$self->errors};
+  return "Amazon EC2 Errors [Request ".$self->request_id."]:\n$errors"
+}
+
 __PACKAGE__->meta->make_immutable();
 
+=back
+
 =head1 AUTHOR
 
 Jeff Kim <cpan@chosec.com>
@@ -45,4 +56,4 @@ under the same terms as Perl itself.
 =cut
 
 no Moose;
-1;
\ No newline at end of file
+1;
