@@ -1,4 +1,5 @@
 package Net::Amazon::EC2::ReservationInfo;
+$Net::Amazon::EC2::ReservationInfo::VERSION = '0.36';
 use Moose;
 
 =head1 NAME
@@ -21,7 +22,7 @@ Unique ID attached to the reservation.
 
 AWS Account id of the person making the reservation.
 
-=item group_set (required)
+=item group_set
 
 An array ref of Net::Amazon::EC2::GroupSet objects.
 
@@ -39,7 +40,7 @@ has 'reservation_id'	=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'owner_id'			=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'group_set'			=> ( 
     is			=> 'ro', 
-    isa			=> 'ArrayRef[Net::Amazon::EC2::GroupSet] | Undef',
+    isa			=> 'ArrayRef[Net::Amazon::EC2::GroupSet]',
     required	=> 1,
     auto_deref	=> 1,
 );
