@@ -1,4 +1,5 @@
 package Net::Amazon::EC2::UserIdGroupPair;
+$Net::Amazon::EC2::UserIdGroupPair::VERSION = '0.36';
 use Moose;
 
 =head1 NAME
@@ -24,10 +25,12 @@ Name of the security group.
 =cut
 
 has 'user_id'       => ( is => 'ro', isa => 'Str', required => 1 );
-has 'group_name'    => ( is => 'ro', isa => 'Str', required => 1 );
+has 'group_name'    => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
 
 __PACKAGE__->meta->make_immutable();
 
+=back
+
 =head1 AUTHOR
 
 Jeff Kim <cpan@chosec.com>
@@ -40,4 +43,4 @@ under the same terms as Perl itself.
 =cut
 
 no Moose;
-1;
\ No newline at end of file
+1;
